=== modified file 'docs/aggregatefunctions.rst'
--- docs/aggregatefunctions.rst	2011-01-14 05:25:23 +0000
+++ docs/aggregatefunctions.rst	2011-01-17 16:58:09 +0000
@@ -1,19 +1,51 @@
 Aggregate Functions
-===================
+===================
 
-*SQL aggregate functions are calculated from values in a column, and return a single value.*
+SQL group (aggregate) functions operate on sets of values. If you use an aggregate function in a statement containing no GROUP BY clause, it is equivalent to grouping on all rows.
 
 General syntax for aggregate functions is: ::
 
 	SELECT "function type" ("column_name")
-	FROM "table_name"
-
-The following are examples of aggregate functions:
-
-    * AVG() - Returns the average value
-    * COUNT() - Returns the number of rows
-    * FIRST() - Returns the first value
-    * LAST() - Returns the last value
-    * MAX() - Returns the largest value
-    * MIN() - Returns the smallest value
-    * SUM() - Returns the sum
+	FROM "table_name";
+
+The following are examples of aggregate functions:
+
+**AVG**:  Return the average value of the argument. (Does not work with temporal values unless first converted to numeric values.)
+
+**BIT_AND**:  Return bitwise and
+
+**BIT_OR**:  Return bitwise or
+
+**BIT_XOR**:  Return bitwise xor
+
+:doc:`count`
+(DISTINCT):  Return the count of a number of different values
+
+:doc:`count`:  Return a count of the number of rows returned
+	
+**GROUP_CONCAT**:  Return a concatenated string
+
+**MAX**:  Return the maximum value
+
+**MIN**:  Return the minimum value
+
+**STD**:  Return the population standard deviation
+
+**STDDEV_POP**:  Return the population standard deviation
+
+**STDDEV_SAMP**:  Return the sample standard deviation
+
+**STDDEV**:  Return the population standard deviation
+
+**SUM**:  Return the sum. (Does not work with temporal values unless first converted to numeric values.)
+
+**VAR_POP**:  Return the population standard variance
+
+**VAR_SAMP**:  Return the sample variance
+
+**VARIANCE**:  Return the population standard variance
+
+.. toctree::
+   :hidden: 
+
+   count

=== added file 'docs/count.rst'
--- docs/count.rst	1970-01-01 00:00:00 +0000
+++ docs/count.rst	2011-01-17 16:58:09 +0000
@@ -0,0 +1,35 @@
+COUNT
+-----
+
+Take the following "Nodes" table, where 'nodes' are user-contributed content:
+
++--------+-------------------+------------+----------------+-------------------+
+|NodeID  |ContributionDate   |NodeSize    |NodePopularity  |UserName           |
++--------+-------------------+------------+----------------+-------------------+
+|1	 |12/22/2005         |160	  |2	           |Smith              |
++--------+-------------------+------------+----------------+-------------------+
+|2	 |08/10/2005	     |190	  |2	           |Johnson            |
++--------+-------------------+------------+----------------+-------------------+
+|3  	 |07/13/2005	     |500	  |5	           |Baldwin            |
++--------+-------------------+------------+----------------+-------------------+
+|4	 |07/15/2005	     |420	  |2               |Smith              |
++--------+-------------------+------------+----------------+-------------------+
+|5	 |12/22/2005         |1000	  |4               |Wood               |
++--------+-------------------+------------+----------------+-------------------+
+|6       |10/2/2005	     |820	  |4	           |Smith              |
++--------+-------------------+------------+----------------+-------------------+
+
+The SQL COUNT function returns the number of rows in a table satisfying the criteria specified in the WHERE clause. If we want to count how many orders has made a customer with CustomerName of Smith, we will use the following SQL COUNT expression: ::
+
+	SELECT COUNT (*) FROM Nodes
+	WHERE UserName = 'Smith'
+
+In the above statement, the COUNT keyword returns the number 3, because the user Smith has made 3 orders in total.
+
+If you don’t specify a WHERE clause when using the COUNT keyword, your statement will simply return the total number of rows in the table, which would be 6 in this example: ::
+
+	SELECT COUNT(*) FROM Nodes
+
+How can we get the number of unique customers that have ordered from our store? We need to use the DISTINCT keyword along with the COUNT function to accomplish that: ::
+
+	SELECT COUNT (DISTINCT UserName) FROM Nodes
\ No newline at end of file

=== modified file 'docs/date_time_data_types.rst'
--- docs/date_time_data_types.rst	2011-01-14 05:20:19 +0000
+++ docs/date_time_data_types.rst	2011-01-17 16:58:09 +0000
@@ -20,15 +20,13 @@
 TIMESTAMP
 ---------
 
-To create a TIMESTAMP column that uses microseconds you simply need to specify TIMESTAMP(6) in your table definition, for example: ::
+To create a TIMESTAMP column that uses microseconds you simply need to specify TIMESTAMP in your table definition, for example: ::
 
 	CREATE TABLE `t1` (
 	`a` INT DEFAULT NULL,
-	`b` TIMESTAMP(6) NULL DEFAULT NULL
+	`b` TIMESTAMP NULL DEFAULT NULL
 	) ENGINE=InnoDB
 
-FIXME: why the number 6 ?
-
 You can then use the following (but note that ON DEFAULT/UPDATE CURRENT_TIMESTAMP works with microseconds as well): ::
 
 	insert into t1 values (1, '2010-01-10 07:32:43.234567');

=== modified file 'docs/functions.rst'
--- docs/functions.rst	2011-01-04 19:30:06 +0000
+++ docs/functions.rst	2011-01-17 16:58:09 +0000
@@ -4,7 +4,7 @@
 Several SQL functions are built into Drizzle--functions perform calculations on data. They can be divided into two general types: 
    
 .. toctree::
-   :maxdepth: 2
+   :maxdepth: 1
 
    aggregatefunctions
    scalarfunctions
\ No newline at end of file

